-- MacPCLtoPDF - by Edward Meendelson - 15 June 2015
-- Coverts PCL print files to PDF format
-- includes GhostPCL  http://ghostscript.com/GhostPCL.html
-- GhostPCL is distributed under the GNU General Public License
-- URW fonts embedded in GhostPCL are distributed under the
--   Aladdin Free Public License
-- This Applescript is distributed under the GNU General Public License

-- To view a PDF automatically after conversion, either add a word with the letter "V"
--   the name of the application (e.g., "MacPCLToPDFviewer") or set the
--   viewAfterConverting property below to true
property viewAfterConverting : false

-- To output A4 either add "A4" to the name of the application
-- or set the outputA4 property below to true
property outputA4 : false

-- do NOT change anything below this line --
--------------------------------------------------

property msgTitle : "MacPCLtoPDF"
property viewPDF : false
property pjlString : " "

on open (theDrop)
	-- checkHostSystem()
	if (count items of theDrop) > 1 then
		tell me to activate
		display dialog "Please drop only one PCL file on me at a time." buttons {"OK"} default button 1 with icon stop with title msgTitle giving up after 10
		error number -128
	end if
	set pclItem to (item 1 of theDrop)
	getMyName()
	makePDF(pclItem, viewPDF)
end open

on run
	-- checkHostSystem()
	set pclItem to choose file with prompt "Choose a PCL file to convert to PDF format:"
	getMyName()
	makePDF(pclItem, viewPDF)
end run

on makePDF(pclItem, viewPDF)
	set isPCLDoc to false
	set extList to {"pcl", "pxl", "prn"}
	tell application "Finder"
		if name extension of (info for pclItem) is in extList then set isPCLDoc to true
	end tell
	
	if isPCLDoc is true then
		set isPCLDoc to ((read file (pclItem as text) from 1 to 2 as data) is data rdat1B45)
		if isPCLDoc is false then
			set isPCLDoc to ((read file (pclItem as text) from 1 to 8 as data) is data rdat1B252D3132333435)
		end if
	end if
	
	if isPCLDoc is false then
		tell me to activate
		display dialog "This file may not be in standard PCL format." & return & return & "Should I try to create a PDF file from it?" buttons {"OK", "Cancel"} default button 2 with title msgTitle
		if button returned of result is "Cancel" then
			error number -128
		end if
	end if
	
	tell application "Finder"
		set sourceItem to POSIX path of pclItem
		set targetPath to characters 1 through -5 of sourceItem as string
		set targetPath to targetPath & ".pdf"
		
		set targetExists to true
		try
			set targetAlias to POSIX file targetPath as alias
		on error
			set targetExists to false
		end try
		
		if targetExists is true then
			tell me to activate
			display dialog "Output file exists:" & return & return & targetPath & return & return & "Overwrite existing output file?" buttons {"OK", "Cancel"} default button 2 with title msgTitle
			if button returned of result is "Cancel" then
				error number -128
			end if
		end if
	end tell
	
	set sourcePosix to quoted form of sourceItem
	set targetPosix to quoted form of targetPath
	
	set thisApp to (path to me) as text
	set pclApp to thisApp & "Contents:Resources:Files:pcl6" as text
	set pclCmd to quoted form of POSIX path of (pclApp as alias)
	
	if outputA4 is true then
		set pjlString to space & "-J" & "\"" & "@PJL SET PAPER = A4" & "\"" & space
	end if
	
	do shell script pclCmd & " -dNOPAUSE -sDEVICE=pdfwrite" & pjlString & "-sOutputFile=" & targetPosix & space & sourcePosix
	
	if viewPDF is true then
		try
			set shellCmd to "open " & targetPosix
			do shell script shellCmd
		on error
			tell me to activate
			display dialog "Could not open output file:" & return & return & targetPath buttons {"OK"} default button 1 with title msgTitle giving up after 10
		end try
	end if
	quit
end makePDF

on getMyName()
	tell application "System Events" to set myName to name of (get properties of (path to me))
	set myName to text 1 thru -5 of myName
	if myName contains "A4" then
		set outputA4 to true
	end if
	if viewAfterConverting is false then
		set viewPDF to false
		if myName contains "v" then
			set viewPDF to true
		end if
	else if viewAfterConverting is true then
		set viewPDF to true
	end if
end getMyName

(*
on checkHostSystem()
	-- Running on Snow Leopard or later?
	set reqVers to 6 -- requires 10.6 Snow Leopard
	set sysVers to ((system attribute "sysv") mod 4096 div 16)
	if sysVers < reqVers then
		tell me to activate
		display dialog "This application runs under OS X 10." & reqVers & " or later, and you seem to have an earlier version of OS X." buttons {"OK"} default button 1 with title msgTitle giving up after 10
		error number -128
	end if
end checkHostSystem
*)

